# Python Diffuse

[![Build Status](https://travis-ci.org/asandeep/diffuse.svg?branch=master)](https://travis-ci.org/asandeep/diffuse)
[![codecov](https://codecov.io/gh/asandeep/diffuse/branch/master/graph/badge.svg)](https://codecov.io/gh/asandeep/diffuse)
[![license](https://img.shields.io/pypi/l/diffuse.svg)](https://github.com/asandeep/diffuse/blob/master/LICENSE)
[![Python Versions](https://img.shields.io/pypi/pyversions/diffuse.svg)](https://pypi.org/project/diffuse/)
[![Package Version](https://img.shields.io/pypi/v/diffuse.svg)](https://pypi.org/project/diffuse/)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Diffuse is yet another python library to run concurrent code.

The library builds upon standard library's `concurrent.futures` module and provides a consistent interface to run your code in separate Threads, Processes or ASyncIO coroutines.
